#!/bin/sh
##############################################################################
#
#  Copyright (c) 2005, Doremi Labs, Inc.
#    All rights reserved.
#
#  Redistribution in source or binary forms, with or without
#  modification, are NOT permitted.
#
#    Doremi Labs, Inc.
#    1020 Chestnut St.
#    Burbank, CA 91506
#    Tel : (818) 562 1101
#    Fax : (818) 562 1109
#
##############################################################################

SIMULATE=0
VERBOSE=0

test $SIMULATE -eq 1 && VERBOSE=1

DOREMI_X_FILES="/doremi/etc/apcupsd
/doremi/etc/apcupsd
/doremi/etc/blacklist.conf
/doremi/etc/certs/css
/doremi/etc/*.sample
/doremi/etc/cpanel.d
/doremi/etc/cron.d
/doremi/etc/cueslib/ecna.xml
/doremi/etc/cueslib/jnior.xml
/doremi/etc/cueslib/jnior2.xml
/doremi/etc/cueslib/jnior expansion module.xml
/doremi/etc/cueslib/Certainty.xml
/doremi/etc/default/*.sample
/doremi/etc/doremi-mib.mib
/doremi/etc/fontconfig/30-zh-enlarge.conf
/doremi/etc/hotplug.d
/doremi/etc/init.d
/doremi/etc/rc.d
/doremi/etc/rc.once
/doremi/etc/release.md5
/doremi/etc/upgrade
/doremi/etc/migrate.d
/doremi/etc/snmp/*.MIB
/doremi/opt/cache
/doremi/opt/bootsequence.txt
/doremi/opt/drmplaylistd/loaded-showplaylist.xml
/doremi/opt/drmplaylistd/tls.pem
/doremi/opt/drmplaylistd/tls.key
/doremi/opt/cinelister/status.xml
/doremi/opt/dbs/doremi.db
/doremi/opt/dbs/smpte.db
/doremi/opt/migrate
/doremi/opt/timestat
/doremi/opt/raidstat
/doremi/opt/smart"

if [ -z "$BACKUP_FOLDER" ]; then
  BACKUP_FOLDER=/data/migrate
fi
if [ -z "$BASE_FOLDER" ]; then
  CATEGORY=$(basename $(dirname $0))
  BASE_FOLDER=${BACKUP_FOLDER}/${CATEGORY}
fi

#
# lists files matching input patterns in first arg folder
#
safe_list_priv ()
{
  local base=$1
  shift
  
  res=$(echo "$*" | sed -e "s_[^\n]*_${base}/&_")
  ls -d $res 2>/dev/null
}

#
# lists files matching input patterns in BASE_FOLDER
#
safe_list ()
{
  local SAVEIFS=$IFS
  IFS=$(echo -en "\n\b")
  
  safe_list_priv ${BASE_FOLDER} "$*"

  IFS=$SAVEIFS
}

#
# checks if file exists in first arg folder
# before deleting.
# accepts regular expressions
#
safe_delete_priv ()
{
  local base=$1
  shift
  
  local items=$(safe_list_priv $base "$*")
  
  for item in $items; do
    if [ -e $item ]; then
      test "$VERBOSE" == "1" && echo "rm -rf $item"
      rm -rf $item
    fi
  done
}

#
# checks if file exists in BASE_FOLDER
# before deleting.
# accepts regular expressions
#
safe_delete ()
{
  local SAVEIFS=$IFS
  IFS=$(echo -en "\n\b")
  
  safe_delete_priv $BASE_FOLDER "$*"

  IFS=$SAVEIFS  
}

#
# checks if file exists on the system
# before copying
# accepts regular expressions
# copies into BASE_FOLDER
#
safe_backup ()
{
  local SAVEIFS=$IFS
  IFS=$(echo -en "\n\b")
  
  local items=$(ls -d $* 2>/dev/null)
    
  for item in $items; do
    test "$VERBOSE" == "1" && echo "mkdir -p ${BASE_FOLDER}/$(dirname $item)"
    mkdir -p ${BASE_FOLDER}/$(dirname $item)
    test "$VERBOSE" == "1" && echo "cp -a $item ${BASE_FOLDER}/$item "
    cp -a $item ${BASE_FOLDER}/$item  
  done

  IFS=$SAVEIFS  
}

#
# checks if file exists in BASE_FOLDER
# before restoring it
# accepts regular expressions
#
safe_restore ()
{
  local SAVEIFS=$IFS
  IFS=$(echo -en "\n\b")
  
  local items=$(safe_list "$*")
  for item in $items; do
    local orig_item=${item/${BASE_FOLDER}//}
    if [ "SIMULATE" == "1" ]; then
      echo "mkdir -p $(dirname $orig_item)"
      if [ -d $item ]; then
        echo "cp -a $item $(dirname $orig_item)"
      else
        echo "cp -a $item $orig_item"
      fi
    else
      test "$VERBOSE" == "1" && echo "mkdir -p $(dirname $orig_item)"
      mkdir -p $(dirname $orig_item)
      if [ -d $item ]; then
        test "$VERBOSE" == "1" && echo "cp -a $item $(dirname $orig_item)"
        cp -a $item $(dirname $orig_item)
      else
        test "$VERBOSE" == "1" && echo "cp -a $item $orig_item"
        cp -a $item $orig_item
      fi
    fi
  done

  IFS=$SAVEIFS  
}

#
# remove unwanted files from backup folder
# specified as first argument
#
exclude_doremi_x_file()
{
  local SAVEIFS=$IFS
  IFS=$(echo -en "\n\b")
  
  safe_delete_priv $1 "$DOREMI_X_FILES"

  IFS=$SAVEIFS  
}
